@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.20 $
+  $Revision: 1.21 $
 
   NT (Notifications) module
 
@@ -40,6 +40,7 @@
 extern int supress_ack_notif;
 extern char * defmail;
 extern int reading_from_mail;
+extern char * forwlog;
 
 /*  Generates a unique file name and returns the full path of the filename 
     for storing notification message.  Creates the file at the same time. 
@@ -659,7 +660,7 @@ overlap_routes get_overlapping_routes_list(char * object){
   
 
   /* filter out the route object itself */
-  result = filter_out_same_origins(result, object);
+  result = UP_filter_out_same_origins(result, object);
 
   /* and fill in the result field  */
   if(result != NULL){
@@ -849,18 +850,18 @@ void NT_send_forw_creation( const char * filename, const char * to_address, cons
 void NT_forw_create_req(const char * object){
 
    FILE * forw_file;
-   char * name;
+   char * filename;
    char * replaced_mtfwheader;
    char * replaced_mtfwtxt;
-       
+
    /* allocate space for name.  32 should be enough for PID */
-   name = (char*)malloc(strlen(tmpdir) + strlen("creat-forw") +32 ); 
+   filename = (char*)malloc(strlen(tmpdir) + strlen("creat-forw") +32 ); 
    
-   sprintf(name, "%s/%s.%i", tmpdir, "creat-forw", getpid());
+   sprintf(filename, "%s/%s.%i", tmpdir, "creat-forw", getpid());
 
    /* create the file */
-   if(( forw_file = fopen(name, "w")) == NULL){
-     fprintf(stderr, "Can't open creation forward file for creating, %s", name);
+   if(( forw_file = fopen(filename, "w")) == NULL){
+     fprintf(stderr, "Can't open creation forward file for creating, %s", filename);
    }
 
    replaced_mtfwheader = UP_replace_globals(mtfwheader);
@@ -879,13 +880,16 @@ void NT_forw_create_req(const char * object){
    fclose(forw_file);
     
    /* send it */ 
-   NT_send_forw_creation(name, humailbox, mailcmd);
+   NT_send_forw_creation(filename, humailbox, mailcmd);
+
+   /* log it */
+   NT_log_ntfy(filename, forwlog);
    
    /* delete it */
-   unlink(name);
+   unlink(filename);
  
    /* free the mem */ 
-   free(name);
+   free(filename);
    free(replaced_mtfwheader);
    free(replaced_mtfwtxt);
 }
