@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.30 $
+  $Revision: 1.31 $
 
   gpg.c - core of the PA module. Contains functions that are used
   to check the PGP authentication in a message.
@@ -11,7 +11,7 @@
   Authors             : Filippo Portera, Daniele Arena
   OSs Tested          : Solaris 7
   ******************/ /******************
-  Copyright (c) 2000                              RIPE NCC
+  Copyright (c) 2000,2001                         RIPE NCC
  
   All Rights Reserved
   
@@ -31,7 +31,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   ***************************************/
 
-
+#include "rip.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,11 +47,6 @@
 #include <sys/time.h>
 #include <sys/param.h>
 
-#include "mm.h" 
-/*#include "misc.h"*/   /* isMIME functions need case insensitive string search()*/
-#include "gpg.h"
-#include "erroutines.h"
-
 extern char EP_outputPrefix[FILENAME_LENGTH];
 extern char EP_keyRing[FILENAME_LENGTH];
 extern char EP_gpgcmd[FILENAME_LENGTH];
@@ -966,8 +961,8 @@ void VerifySignAndExplodeFile(EPNodePtr ptr) {
     }
     
   unlink(ptr->file);
-  free(ptr->file);
-  ptr->file = strdup(oFile);
+  UT_free(ptr->file);
+  ptr->file = UT_strdup(oFile);
   if (sd1[0] != 0)  close ( sd1[0] ); 
 }
 
