@@ -1,5 +1,5 @@
 /***************************************
-  $Revision: 1.58 $
+  $Revision: 1.60 $
 
   Example code: A server for a client to connect to.
 
@@ -21,7 +21,7 @@
         ottrey (08/03/1999) Modified.
         joao   (22/06/1999) Modified.
   ******************/ /******************
-  Copyright (c) 1999                              RIPE NCC
+  Copyright (c) 1999, 2000, 2001                  RIPE NCC
  
   All Rights Reserved
   
@@ -41,6 +41,8 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/
 
+#include "rip.h"
+
 #include <ctype.h>
 
 #include <sys/types.h>
@@ -49,41 +51,6 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 
-#include "thread.h"
-#include "rxroutines.h"
-#include "sk.h"
-/*
-#include "objects.h"
-*/
-#include "constants.h"
-
-#include "ca_configFns.h"
-#include "ca_dictionary.h"
-#include "ca_macros.h"
-#include "ca_srcAttribs.h"
-
-#include "mysql_driver.h"
-#include "access_control.h"
-#include "ud.h"
-#include "ud_tr.h"
-#include "server.h"
-
-#include "rp.h"
-#include "memwrap.h"
-
-#include "ta.h"
-
-#include "protocol_whois.h"
-#include "protocol_mirror.h"
-#include "protocol_config.h"
-
-/*+ String sizes +*/
-#define STR_S   63
-#define STR_M   255
-#define STR_L   1023
-#define STR_XL  4095
-#define STR_XXL 16383
-
 /* Listening sockets */
 int SV_whois_sock;
 int SV_config_sock;
@@ -214,35 +181,39 @@ int counter_wait(svr_counter_t *cst, int limit )
 
 /*++++++++++++++++++++++++++++++++++++++
 
-  Loading the radix tree. Started as a separate thread.
+  Initialize the radix tree - all trees are added to the forest in
+  a locked state.  As each tree finishes loading (from radix_load()),
+  it is unlocked.
 
-  Author:
-    marek
   ++++++++++++++++++++++++++++++++++++++*/
-void radix_init(void){
-  int i;
-  ca_dbSource_t *source_hdl;
+static void 
+radix_init(void)
+{
+    int i;
+    ca_dbSource_t *source_hdl;
 
-  wr_log_set(0);
-  /* this needs to be done in two loops, 
-     because the trees must be created asap (first loop)
-     and then locked until they are populated in the second loop
-  */
- 
-  TH_init_read_write_lockw(&rx_forest_rwlock);
-    
-  for(i=0; (source_hdl = ca_get_SourceHandleByPosition(i))!=NULL ; i++){   
-    dieif( RP_init_trees( source_hdl ) != RP_OK );
-  }
-  
-  for(i=0; (source_hdl = ca_get_SourceHandleByPosition(i))!=NULL ; i++){   
-    dieif( RP_sql_load_reg( source_hdl ) != RP_OK ); 
-  }
-  
-  wr_log_set(0); /* switch on/off the memory leak detector */
-/*  pthread_mutex_unlock( &radix_initializing_lock );  */
+    TH_init_read_write_lockw(&rx_forest_rwlock);
+    for(i=0; (source_hdl = ca_get_SourceHandleByPosition(i))!=NULL ; i++){   
+        dieif( RP_init_trees( source_hdl ) != RP_OK );
+    }
+}
 
-  pthread_exit((void *)0);
+/*++++++++++++++++++++++++++++++++++++++
+
+  Load the radix tree - all trees are initialized from the appropriate
+  SQL tables.  As each tree finishes loading (from radix_load()), it is
+  unlocked.  They must be created by the radix_init() function.
+
+  ++++++++++++++++++++++++++++++++++++++*/
+static void
+radix_load(void)
+{
+    int i;
+    ca_dbSource_t *source_hdl;
+
+    for(i=0; (source_hdl = ca_get_SourceHandleByPosition(i))!=NULL ; i++){   
+        dieif( RP_sql_load_reg( source_hdl ) != RP_OK ); 
+    }
 }
 
 
@@ -390,7 +361,7 @@ void *SV_do_child(void *varg)
   ER_dbg_va(FAC_TH, ASP_TH_NEW, 
 	    "%s threads-- = %d", args->name, curclients); 
 
-  free(args);
+  UT_free(args);
 
   return NULL; /* exit the thread */
 } /* SV_do_child */
@@ -462,7 +433,7 @@ static void  *main_loop(void *arg) {
        and expect SV_do_child to free it after use. 
        Caveat: the counter remains where it was, we just copy the pointer.
     */
-    argcopy = malloc( sizeof(svr_args) );
+    argcopy = UT_malloc( sizeof(svr_args) );
     memcpy( argcopy, argset, sizeof(svr_args) );
     TH_create( SV_do_child, (void *)argcopy );
   } 
@@ -499,14 +470,14 @@ void SV_concurrent_server(int sock, int limit,  char *name,
 {
   svr_args *args;
   
-  dieif( wr_calloc((void **)&args, 1, sizeof(svr_args)) != UT_OK);  
+  args = (svr_args *)UT_calloc(1, sizeof(svr_args));
 
   args->accept_sock=sock;
   args->limit=limit;
   args->name=name;
   args->function=do_function;
+  args->counter = (svr_counter_t *)UT_calloc(1, sizeof(svr_counter_t));
 
-  dieif( wr_calloc((void **)&(args->counter),1,sizeof(svr_counter_t)) != UT_OK);  
   pthread_mutex_init( &(args->counter->lock), NULL );
   pthread_cond_init(  &(args->counter->cond), NULL );
   args->counter->count = 0;
@@ -634,10 +605,10 @@ int SV_start(char *pidfile) {
      TR_recover(db_connection);
      /* free resources */
      SQ_close_connection(db_connection);
-     free(db_host);
-     free(db_name);
-     free(db_user);
-     free(db_passwd);
+     UT_free(db_host);
+     UT_free(db_name);
+     UT_free(db_user);
+     UT_free(db_passwd);
      
      update_mode = ca_get_srcmode(source_hdl);
      if(IS_UPDATE(update_mode)) {
@@ -652,14 +623,10 @@ int SV_start(char *pidfile) {
   }   
   SV_update_sock[source+1]=-1; /* end of socket array */
    
-   /* Initialise the radix tree (separate thread[s])
+  /* Initialise the radix trees
      already can allow socket connections, because the trees will 
      be created locked, and will be unlocked when loaded */
-
-/*   pthread_mutex_lock( &radix_initializing_lock );  */
-  TH_create((void *(*)(void *))radix_init, NULL);
-/*  pthread_mutex_lock( &radix_initializing_lock );  */
-  
+  radix_init();
  
   /* Now.... accept() calls block until they get a connection
      so to listen on more than one port we need more
@@ -671,6 +638,10 @@ int SV_start(char *pidfile) {
   SV_concurrent_server(SV_config_sock, 0, "config", PC_interact);
   /* Create master thread for mirror threads */
   SV_concurrent_server(SV_mirror_sock, 0, "mirror", PM_interact);
+
+  /* Load the radix trees - this must be done before the 
+     updates are allowed to proceed */
+  radix_load();
   
   /* Walk through the sources and */
   /* run update thread for every source with CANUPD == 'y' */
@@ -695,7 +666,7 @@ int SV_start(char *pidfile) {
 	     fprintf(stderr,"Source [%s] Mode STATIC\n", source_name);
 	     ER_inf_va(FAC_SV, 0xFFFFFF, "Source [%s] Mode STATIC", source_name);
      }
-     free(source_name); /* because ca_* functions return copies */   
+     UT_free(source_name); /* because ca_* functions return copies */   
    }    
   /* terminate the thread */
   /* XXX not return becase then we terminate the whole process */
